@@ -8,4 +8,10 @@ class InvalidCommand(UsefulException):
   def __init__(self, klass, exception, *args, **kwargs):
     self.klass = klass
     self.exception = exception
-    super(InvalidCommand, self).__init__(*args, **kwargs)
\ No newline at end of file
+    super(InvalidCommand, self).__init__(*args, **kwargs)
+
+class NeedsRoot(UsefulException):
+  pass
+
+class CommandError(UsefulException):
+  pass
\ No newline at end of file
