@@ -40,10 +40,9 @@ class CommandRouter(object):
   def find(self):
     for command in self.commands:
       instance = self.commands[command]()
-      
-      try:
-        arguments = docopt.docopt(instance.__doc__ or '', help=False)
 
+      try:
+        arguments = docopt.docopt(instance.__doc__, help=False)
       except docopt.DocoptExit:
         # The arguments can't be processed by this command
         continue
@@ -70,7 +69,7 @@ class CommandRouter(object):
     regex = re.compile(r"\suseful\.py\s(.+)")
 
     for command in self.commands:
-      for line in (self.commands[command].__doc__ or '').split("\n"):
+      for line in (self.commands[command].__doc__).split("\n"):
         result = regex.search(line)
         if result:
           possible_commands.append(result.group(1))
@@ -83,6 +82,4 @@ class CommandRouter(object):
       module = importlib.import_module('usefulpy.logic.%s' % module_name)
       for name, obj in inspect.getmembers(module):
         if inspect.isclass(obj):
-          self.commands[name] = obj
-
-
+          self.commands[name] = obj
\ No newline at end of file
