@@ -2,10 +2,13 @@ from usefulpy import runners, logic
 from usefulpy.helpers import *
 
 class Untar(logic.BaseCommand):
-  signature = "untar <source> [--download] [<destination>] [-D]"
+  """
+  Usage:
+    useful.py untar <source> [--download] [<destination>] [-D]
 
-  def is_valid(self):
-    return self.arguments['untar']
+  Options:
+    -D, --dry    Print the commands to stdout
+  """
 
   def run(self):
     runner = runners.BashRunner(self.arguments['--dry'])
