@@ -2,10 +2,13 @@ from usefulpy import runners, logic
 from usefulpy.helpers import *
 
 class NewUser(logic.BaseCommand):
-  signature = "new user <name> [--home=home] [-D]"
+  """
+  Usage:
+    useful.py user new <name> [--home=home] [-D]
 
-  def is_valid(self):
-    return self.arguments['new'] and self.arguments['user']
+  Options:
+    -D, --dry    Print the commands to stdout
+  """
 
   def run(self):
     runner = runners.BashRunner(self.arguments['--dry'])
