@@ -12,3 +12,5 @@ def handle():
   except exceptions.UsefulException as e:
     print "(Not)UsefulException: A generic exception has occurred. Original exception below:"
     raise e
+  except (exceptions.NeedsRoot, IOError):
+    print "System IO error. Maybe you need to be root?"
